<?php
// $Id: l10n_install.profile,v 1.1.2.3.2.3 2010/10/13 12:59:58 goba Exp $

/**
 * @file
 * This is a very quick prototype of a localized Drupal installer.
 *
 * It is fed from localize.drupal.org. Needs more serious development. Inspired
 * by the Open Atrium localized installer but is not yet as advanced (and will
 * need to be more generic to support any kind of install profiles).
 */

/**
 * Source for localization files.
 */
define('L10N_INSTALL_SERVER_URL', 'http://ftp.drupal.org/files/translations');

/**
 * Implements hook_form_FORM_ID_alter().
 *
 * Allows the profile to alter the site configuration form.
 */
function l10n_install_form_install_configure_form_alter(&$form, $form_state) {
  // Pre-populate the site name with the server name.
  $form['site_information']['site_name']['#default_value'] = $_SERVER['SERVER_NAME'];
}

/**
 * Implement hook_install_tasks().
 */
function l10n_install_install_tasks($install_state) {
  // Determine whether translation import tasks will need to be performed.
  $needs_translations = count($install_state['locales']) > 1 && !empty($install_state['parameters']['locale']) && $install_state['parameters']['locale'] != 'en';

  return array(
    'l10n_install_import_translation' => array(
      'display_name' => st('Set up translations'),
      'display' => $needs_translations,
      'run' => $needs_translations ? INSTALL_TASK_RUN_IF_NOT_COMPLETED : INSTALL_TASK_SKIP,
    ),
  );
}

/**
 * Implement hook_install_tasks_alter().
 *
 * Perform actions to set up the site for this profile.
 */
function l10n_install_install_tasks_alter(&$tasks, $install_state) {
  // Remove core steps for translation imports.
  unset($tasks['install_import_locales']);
  unset($tasks['install_import_locales_remaining']);
}

/**
 * Installation step callback.
 *
 * @param $install_state
 *   An array of information about the current installation state.
 */
function l10n_install_import_translation(&$install_state) {
  include_once DRUPAL_ROOT . '/includes/locale.inc';
  $install_locale = $install_state['parameters']['locale'];

  // Enable installation language as default site language.
  locale_add_language($install_locale, NULL, NULL, NULL, '', NULL, 1, TRUE);

  // @todo: inelegant method to overcome that -dev versions might be running.
  // Just fall back on alpha6 for now, the latest alpha version.
  $version = '7.0-beta1'; // str_replace('-dev', '', VERSION);

  // @todo: this will also time out / reach memory limits on certain
  // underpowered PHP installations. We should integrate a batch process for
  // importing the downloaded file (existing issue with some code available).
  $po_url = L10N_INSTALL_SERVER_URL .'/7.x/drupal/drupal-'. $version .'.'. $install_locale .'.po';
  $result = drupal_http_request($po_url);

  if ($result->code == 200) {
    include_once 'includes/locale.inc';
    $tempfile = tempnam(file_directory_temp(), 'l10n-install');
    file_put_contents($tempfile, $result->data);

    $file = (object) array('uri' => $tempfile, 'filename' => basename($tempfile));
    if (_locale_import_po($file, $install_locale, LOCALE_IMPORT_KEEP, 'default')) {
      drupal_set_message(t('Downloaded translation import of %file successful.', array('%file' => basename($po_url))));
    }
    else {
      drupal_set_message(t('Downloaded translation import failed.'), 'error');
    }
  }
  else {
    drupal_set_message(t('Unable to download translations from @url.', array('@url' => $po_url)), 'error');
  }

  // Set up l10n_client and inform the admin about it.
  global $user;
  variable_set('l10n_client_use_server', 1);
  variable_set('l10n_client_server', 'http://localize.drupal.org');
  drupal_set_message(t('Localization client is set up to share your translations with <a href="@localize">localize.drupal.org</a>. Each participating user should have a localize.drupal.org account and set up their API key on their user profile page. <a href="@edit-profile">Set up yours</a>.', array('@localize' => 'http://localize.drupal.org', '@edit-profile' => url('user/' . $user->uid . '/edit'))));
}
